@@ -1,80 +1,9 @@
-import random
 from collections import defaultdict
 import numpy as np
 import gensim
 from joblib import Parallel, delayed
 from tqdm import tqdm
-
-
-def parallel_generate_walks(d_graph, global_walk_length, num_walks, cpu_num, sampling_strategy=None,
-                            num_walks_key=None, walk_length_key=None, neighbors_key=None, probabilities_key=None,
-                            first_travel_key=None, quiet=False):
-    """
-    Generates the random walks which will be used as the skip-gram input.
-    :return: List of walks. Each walk is a list of nodes.
-    """
-
-    walks = list()
-
-
-
-    if not quiet:
-        pbar = tqdm(total=num_walks, desc='Generating walks (CPU: {})'.format(cpu_num))
-
-    for n_walk in range(num_walks):
-
-        # Update progress bar
-        if not quiet:
-            pbar.update(1)
-
-        # Shuffle the nodes
-        shuffled_nodes = list(d_graph.keys())
-        random.shuffle(shuffled_nodes)
-
-        # Start a random walk from every node
-        for source in shuffled_nodes:
-
-            # Skip nodes with specific num_walks
-            if source in sampling_strategy and \
-                    num_walks_key in sampling_strategy[source] and \
-                    sampling_strategy[source][num_walks_key] <= n_walk:
-                continue
-
-            # Start walk
-            walk = [source]
-
-            # Calculate walk length
-            if source in sampling_strategy:
-                walk_length = sampling_strategy[source].get(walk_length_key, global_walk_length)
-            else:
-                walk_length = global_walk_length
-
-            # Perform walk
-            while len(walk) < walk_length:
-
-                walk_options = d_graph[walk[-1]].get(neighbors_key, None)
-
-                # Skip dead end nodes
-                if not walk_options:
-                    break
-
-                if len(walk) == 1:  # For the first step
-                    probabilities = d_graph[walk[-1]][first_travel_key]
-                    walk_to = np.random.choice(walk_options, size=1, p=probabilities)[0]
-                else:
-                    probabilities = d_graph[walk[-1]][probabilities_key][walk[-2]]
-                    walk_to = np.random.choice(walk_options, size=1, p=probabilities)[0]
-
-                walk.append(walk_to)
-
-            walk = list(map(str, walk))  # Convert all to strings
-
-            walks.append(walk)
-
-    if not quiet:
-        pbar.close()
-
-    return walks
+from .parallel import parallel_generate_walks
 
 
 class Node2Vec:
